import { IPosition, LspWsConnection } from 'lsp-editor-adapter';
import { CodeMirror, CodeMirrorAdapterExtension } from './codemirror';
import { JupyterFrontEnd } from '@jupyterlab/application';
import { CodeJumper } from '@krassowski/jupyterlab_go_to_definition/lib/jumpers/jumper';
import { CodeEditor } from '@jupyterlab/codeeditor';
import { IRenderMimeRegistry } from '@jupyterlab/rendermime';
import * as lsProtocol from 'vscode-languageserver-protocol';
import { FreeTooltip } from '../free_tooltip';
import { IDocumentWidget } from '@jupyterlab/docregistry';
import { VirtualEditor } from '../virtual/editor';
import { VirtualDocument } from '../virtual/document';
import { Signal } from '@phosphor/signaling';
import { IEditorPosition } from '../positioning';
interface IDocumentConnectedData {
    document: VirtualDocument;
    connection: LspWsConnection;
}
/**
 * Foreign code: low level adapter is not aware of the presence of foreign languages;
 * it operates on the virtual document and must not attempt to infer the language dependencies
 * as this would make the logic of inspections caching impossible to maintain, thus the WidgetAdapter
 * has to handle that, keeping multiple connections and multiple virtual documents.
 */
export declare abstract class JupyterLabWidgetAdapter {
    app: JupyterFrontEnd;
    connections: Map<VirtualDocument.id_path, LspWsConnection>;
    jumper: CodeJumper;
    adapter: CodeMirrorAdapterExtension;
    rendermime_registry: IRenderMimeRegistry;
    widget: IDocumentWidget;
    private invoke_command;
    protected document_connected: Signal<JupyterLabWidgetAdapter, IDocumentConnectedData>;
    protected constructor(app: JupyterFrontEnd, rendermime_registry: IRenderMimeRegistry, invoke: string);
    abstract virtual_editor: VirtualEditor;
    abstract readonly document_path: string;
    abstract readonly language: string;
    readonly root_path: string;
    abstract get_document_content(): string;
    abstract find_ce_editor(cm_editor: CodeMirror.Editor): CodeEditor.IEditor;
    invoke_completer(): Promise<any>;
    readonly main_connection: LspWsConnection;
    connect(virtual_document: VirtualDocument): Promise<void>;
    handle_jump(locations: lsProtocol.Location[], language: string): void;
    create_adapter(virtual_document: VirtualDocument, connection: LspWsConnection): void;
    get_doc_position_from_context_menu(): IPosition;
    protected create_tooltip(markup: lsProtocol.MarkupContent, cm_editor: CodeMirror.Editor, position: IEditorPosition): FreeTooltip;
}
export {};
