/// <reference types="@types/codemirror" />
import { VirtualDocument } from './document';
import { IOverridesRegistry } from '../magics/overrides';
import { IForeignCodeExtractorsRegistry } from '../extractors/types';
import { CodeMirror } from '../adapters/codemirror';
import { IEditorPosition, IRootPosition, IVirtualPosition } from '../positioning';
/**
 * VirtualEditor extends the CodeMirror.Editor interface; its subclasses may either
 * fast-forward any requests to an existing instance of the CodeMirror.Editor
 * (using ES6 Proxy), or implement custom behaviour, allowing for the use of
 * virtual documents representing code in complex entities such as notebooks.
 */
export declare abstract class VirtualEditor implements CodeMirror.Editor {
    virtual_document: VirtualDocument;
    overrides_registry: IOverridesRegistry;
    code_extractors: IForeignCodeExtractorsRegistry;
    constructor(language: string, path: string, overrides_registry: IOverridesRegistry, foreign_code_extractors: IForeignCodeExtractorsRegistry);
    abstract get_editor_index(position: IVirtualPosition): number;
    abstract transform_virtual_to_source(position: CodeMirror.Position): CodeMirror.Position;
    abstract transform_editor_to_root(cm_editor: CodeMirror.Editor, position: IEditorPosition): IRootPosition;
    abstract get_cm_editor(position: IRootPosition): CodeMirror.Editor;
    abstract addEventListener(type: string, listener: EventListenerOrEventListenerObject): void;
    get_virtual_document(position: IRootPosition): {
        document: VirtualDocument;
        virtual_position: IVirtualPosition;
    };
    document_as_root_position(position: IRootPosition): VirtualDocument;
    root_position_to_virtual_position(position: IRootPosition): IVirtualPosition;
    get_editor_at_root_position(root_position: IRootPosition): CodeMirror.Editor;
    root_position_to_editor_position(root_position: IRootPosition): IEditorPosition;
}
export interface VirtualEditor extends CodeMirror.Editor {
}
