"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const document_1 = require("./document");
/**
 * VirtualEditor extends the CodeMirror.Editor interface; its subclasses may either
 * fast-forward any requests to an existing instance of the CodeMirror.Editor
 * (using ES6 Proxy), or implement custom behaviour, allowing for the use of
 * virtual documents representing code in complex entities such as notebooks.
 */
class VirtualEditor {
    constructor(language, path, overrides_registry, foreign_code_extractors) {
        this.virtual_document = new document_1.VirtualDocument(language, path, overrides_registry, foreign_code_extractors, false);
    }
    // TODO .root is not really needed as we are in editor now...
    // TODO remove this function
    get_virtual_document(position) {
        return {
            document: this.document_as_root_position(position),
            virtual_position: this.root_position_to_virtual_position(position)
        };
    }
    document_as_root_position(position) {
        let root_as_source = position;
        return this.virtual_document.root.document_at_source_position(root_as_source);
    }
    root_position_to_virtual_position(position) {
        let root_as_source = position;
        return this.virtual_document.root.virtual_position_at_document(root_as_source);
    }
    get_editor_at_root_position(root_position) {
        return this.virtual_document.root.get_editor_at_source_line(root_position);
    }
    root_position_to_editor_position(root_position) {
        return this.virtual_document.root.transform_source_to_editor(root_position);
    }
}
exports.VirtualEditor = VirtualEditor;
