/// <reference types="@types/codemirror" />
/// <reference types="@types/codemirror/codemirror-showhint" />
/// <reference types="codemirror/searchcursor" />
import { Notebook, NotebookPanel } from '@jupyterlab/notebook';
import { Cell } from '@jupyterlab/cells';
import { ShowHintOptions } from 'codemirror';
import { IOverridesRegistry } from '../../magics/overrides';
import { IForeignCodeExtractorsRegistry } from '../../extractors/types';
import { VirtualEditor } from '../editor';
import CodeMirror = require('codemirror');
import { IEditorPosition, IRootPosition, ISourcePosition, IVirtualPosition } from '../../positioning';
export declare class VirtualEditorForNotebook extends VirtualEditor {
    notebook: Notebook;
    notebook_panel: NotebookPanel;
    cell_to_corresponding_source_line: Map<Cell, number>;
    cm_editor_to_cell: Map<CodeMirror.Editor, Cell>;
    language: string;
    constructor(notebook_panel: NotebookPanel, language: string, overrides_registry: IOverridesRegistry, foreign_code_extractors: IForeignCodeExtractorsRegistry, path: string);
    transform_virtual_to_source(position: IVirtualPosition): ISourcePosition;
    transform_from_notebook_to_root(cell: Cell, position: CodeMirror.Position): IRootPosition;
    transform_editor_to_root(cm_editor: CodeMirror.Editor, position: IEditorPosition): IRootPosition;
    transform_from_root_to_editor(pos: IRootPosition): CodeMirror.Position;
    get_editor_index(position: IVirtualPosition): number;
    get_cm_editor(position: IRootPosition): CodeMirror.Editor;
    showHint: (options: ShowHintOptions) => void;
    state: any;
    addKeyMap(map: string | CodeMirror.KeyMap, bottom?: boolean): void;
    addLineClass(line: any, where: string, _class_: string): CodeMirror.LineHandle;
    addLineWidget(line: any, node: HTMLElement, options?: CodeMirror.LineWidgetOptions): CodeMirror.LineWidget;
    addOverlay(mode: any, options?: any): void;
    addPanel(node: HTMLElement, options?: CodeMirror.ShowPanelOptions): CodeMirror.Panel;
    charCoords(pos: IRootPosition, mode?: 'window' | 'page' | 'local'): {
        left: number;
        right: number;
        top: number;
        bottom: number;
    };
    coordsChar(object: {
        left: number;
        top: number;
    }, mode?: 'window' | 'page' | 'local'): IRootPosition;
    cursorCoords(where?: boolean, mode?: 'window' | 'page' | 'local'): {
        left: number;
        top: number;
        bottom: number;
    };
    cursorCoords(where?: IRootPosition | null, mode?: 'window' | 'page' | 'local'): {
        left: number;
        top: number;
        bottom: number;
    };
    readonly any_editor: CodeMirror.Editor;
    defaultCharWidth(): number;
    defaultTextHeight(): number;
    endOperation(): void;
    execCommand(name: string): void;
    getDoc(): CodeMirror.Doc;
    get_editor_at_root_line(pos: IRootPosition): CodeMirror.Editor;
    getTokenAt(pos: IRootPosition, precise?: boolean): CodeMirror.Token;
    getTokenTypeAt(pos: IRootPosition): string;
    get_cell_at(pos: IVirtualPosition): Cell;
    get_editor_at_virtual_line(pos: IVirtualPosition): CodeMirror.Editor;
    getValue(seperator?: string): string;
    getWrapperElement(): HTMLElement;
    heightAtLine(line: any, mode?: 'window' | 'page' | 'local', includeWidgets?: boolean): number;
    isReadOnly(): boolean;
    lineAtHeight(height: number, mode?: 'window' | 'page' | 'local'): number;
    off(eventName: string, handler: (instance: CodeMirror.Editor) => void): void;
    off(eventName: 'change', handler: (instance: CodeMirror.Editor, change: CodeMirror.EditorChangeLinkedList) => void): void;
    off(eventName: 'changes', handler: (instance: CodeMirror.Editor, change: CodeMirror.EditorChangeLinkedList[]) => void): void;
    off(eventName: 'beforeChange', handler: (instance: CodeMirror.Editor, change: CodeMirror.EditorChangeCancellable) => void): void;
    off(eventName: 'cursorActivity', handler: (instance: CodeMirror.Editor) => void): void;
    off(eventName: 'beforeSelectionChange', handler: (instance: CodeMirror.Editor, selection: {
        head: CodeMirror.Position;
        anchor: CodeMirror.Position;
    }) => void): void;
    off(eventName: 'viewportChange', handler: (instance: CodeMirror.Editor, from: number, to: number) => void): void;
    off(eventName: 'gutterClick', handler: (instance: CodeMirror.Editor, line: number, gutter: string, clickEvent: Event) => void): void;
    off(eventName: 'focus', handler: (instance: CodeMirror.Editor) => void): void;
    off(eventName: 'blur', handler: (instance: CodeMirror.Editor) => void): void;
    off(eventName: 'scroll', handler: (instance: CodeMirror.Editor) => void): void;
    off(eventName: 'update', handler: (instance: CodeMirror.Editor) => void): void;
    off(eventName: 'renderLine', handler: (instance: CodeMirror.Editor, line: CodeMirror.LineHandle, element: HTMLElement) => void): void;
    off(eventName: 'mousedown' | 'dblclick' | 'touchstart' | 'contextmenu' | 'keydown' | 'keypress' | 'keyup' | 'cut' | 'copy' | 'paste' | 'dragstart' | 'dragenter' | 'dragover' | 'dragleave' | 'drop', handler: (instance: CodeMirror.Editor, event: Event) => void): void;
    off(eventName: string, handler: (doc: CodeMirror.Doc, event: any) => void): void;
    on(eventName: string, handler: (instance: CodeMirror.Editor) => void): void;
    on(eventName: 'change', handler: (instance: CodeMirror.Editor, change: CodeMirror.EditorChangeLinkedList) => void): void;
    on(eventName: 'changes', handler: (instance: CodeMirror.Editor, change: CodeMirror.EditorChangeLinkedList[]) => void): void;
    on(eventName: 'beforeChange', handler: (instance: CodeMirror.Editor, change: CodeMirror.EditorChangeCancellable) => void): void;
    on(eventName: 'cursorActivity', handler: (instance: CodeMirror.Editor) => void): void;
    on(eventName: 'beforeSelectionChange', handler: (instance: CodeMirror.Editor, selection: {
        head: CodeMirror.Position;
        anchor: CodeMirror.Position;
    }) => void): void;
    on(eventName: 'viewportChange', handler: (instance: CodeMirror.Editor, from: number, to: number) => void): void;
    on(eventName: 'gutterClick', handler: (instance: CodeMirror.Editor, line: number, gutter: string, clickEvent: Event) => void): void;
    on(eventName: 'focus', handler: (instance: CodeMirror.Editor) => void): void;
    on(eventName: 'blur', handler: (instance: CodeMirror.Editor) => void): void;
    on(eventName: 'scroll', handler: (instance: CodeMirror.Editor) => void): void;
    on(eventName: 'update', handler: (instance: CodeMirror.Editor) => void): void;
    on(eventName: 'renderLine', handler: (instance: CodeMirror.Editor, line: CodeMirror.LineHandle, element: HTMLElement) => void): void;
    on(eventName: 'mousedown' | 'dblclick' | 'touchstart' | 'contextmenu' | 'keydown' | 'keypress' | 'keyup' | 'cut' | 'copy' | 'paste' | 'dragstart' | 'dragenter' | 'dragover' | 'dragleave' | 'drop', handler: (instance: CodeMirror.Editor, event: Event) => void): void;
    on(eventName: 'overwriteToggle', handler: (instance: CodeMirror.Editor, overwrite: boolean) => void): void;
    on(eventName: string, handler: (doc: CodeMirror.Doc, event: any) => void): void;
    addEventListener(type: string, listener: EventListenerOrEventListenerObject): void;
    forEveryBlockEditor(callback: (cm_editor: CodeMirror.Editor) => any, monitor_for_new_blocks?: boolean): void;
}
